summaryrefslogtreecommitdiff
path: root/src/systemd/sd-network.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/systemd/sd-network.h')
-rw-r--r--src/systemd/sd-network.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/systemd/sd-network.h b/src/systemd/sd-network.h
index dede7aea3..47731c262 100644
--- a/src/systemd/sd-network.h
+++ b/src/systemd/sd-network.h
@@ -64,7 +64,7 @@ int sd_network_get_dns(char ***addr);
* reperesentations of IP addresses */
int sd_network_get_ntp(char ***addr);
/* Get state from ifindex.
* Possible states:
* pending: udev is still processing the link, we don't yet know if we will manage it
* failed: networkd failed to manage the link
@@ -75,7 +75,7 @@ int sd_network_get_ntp(char ***addr);
* Possible return codes:
* -ENODATA: networkd is not aware of the link
*/
-int sd_network_link_get_state(int ifindex, char **state);
+int sd_network_link_get_setup_state(int ifindex, char **state);
/* Get operatinal state from ifindex.
* Possible states:
@@ -64,7 +64,7 @@ int sd_network_get_dns(char ***addr);
* reperesentations of IP addresses */
int sd_network_get_ntp(char ***addr);
-/* Get state from ifindex.
+/* Get setup state from ifindex.
* Possible states:
* pending: udev is still processing the link, we don't yet know if we will manage it